<?php
/* Copyright (C) 2007-2015 Laurent Destailleur  <eldy@users.sourceforge.net>
 * Copyright (C) 2020      Open-DSI             <support@open-dsi.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 *	    \file       htdocs/pdfdownloadnotifier/admin/setup.php
 *		\ingroup    pdfdownloadnotifier
 *		\brief      Page to setup pdfdownloadnotifier module
 */

// Change this following line to use the correct relative path (../, ../../, etc)
$res=0;
if (! $res && file_exists("../../main.inc.php")) $res=@include '../../main.inc.php';			// to work if your module directory is into a subdir of root htdocs directory
if (! $res && file_exists("../../../main.inc.php")) $res=@include '../../../main.inc.php';		// to work if your module directory is into a subdir of root htdocs directory
if (! $res) die("Include of main fails");
require_once DOL_DOCUMENT_ROOT.'/core/lib/admin.lib.php';
require_once DOL_DOCUMENT_ROOT.'/core/lib/functions2.lib.php';
require_once DOL_DOCUMENT_ROOT.'/core/class/html.form.class.php';
dol_include_once('/pdfdownloadnotifier/class/actions_pdfdownloadnotifier.class.php');
dol_include_once('/pdfdownloadnotifier/class/html.formpdfdownloadnotifier.class.php');
dol_include_once('/pdfdownloadnotifier/lib/pdfdownloadnotifier.lib.php');

$langs->load("admin");
$langs->load("pdfdownloadnotifier@pdfdownloadnotifier");
$langs->load("opendsi@pdfdownloadnotifier");

if (!$user->admin) accessforbidden();

$action = GETPOST('action','alpha');

$actionspdfdownloadnotifier = new ActionsPdfDownloadNotifier($db);
$element_list = $actionspdfdownloadnotifier->getElementList();
if (!is_array($element_list)) {
	setEventMessages($actionspdfdownloadnotifier->error, $actionspdfdownloadnotifier->errors, 'errors');
}
$email_template_list = $actionspdfdownloadnotifier->getEmailTemplateList();
if (!is_array($email_template_list)) {
	setEventMessages($actionspdfdownloadnotifier->error, $actionspdfdownloadnotifier->errors, 'errors');
}


/*
 *	Actions
 */
$error = 0;
$errors = array();
if ($action == 'set_settings_options') {
	$res = dolibarr_set_const($db, 'PDFDOWNLOADNOTIFIER_EMAIL_MODEL_USED_TO_NOTIFY_BY_EMAIL', GETPOST('PDFDOWNLOADNOTIFIER_EMAIL_MODEL_USED_TO_NOTIFY_BY_EMAIL', 'int'), 'chaine', 0, '', 0);
	if ($res < 0) {
		$error++;
		$errors[] = $db->lasterror();
	}
	if (!$error) {
		$res = dolibarr_set_const($db, 'PDFDOWNLOADNOTIFIER_DEFAULT_SEND_TO', GETPOST('PDFDOWNLOADNOTIFIER_DEFAULT_SEND_TO', 'alpha'), 'chaine', 0, '', 0);
		if ($res < 0) {
			$error++;
			$errors[] = $db->lasterror();
		}
	}
} elseif ($action == 'set_elements_options') {
	foreach ($element_list as $element_type => $element_info) {
		$element_prop = getElementProperties($element_type);
		if (is_array($element_prop) && $conf->{$element_prop['module']}->enabled) {
			$key = strtoupper($element_type);
			$emailNotifyContactTypeConstName = 'PDFDOWNLOADNOTIFIER_NOTIFY_CONTACT_TYPE_BY_EMAIL_' . $key;
			$res = dolibarr_set_const($db, $emailNotifyContactTypeConstName, implode(',', GETPOST($emailNotifyContactTypeConstName, 'array')), 'chaine', 0, '', 0);
			if ($res < 0) {
				$error++;
				$errors[] = $db->lasterror();
				break;
			}
		}
	}
} elseif (preg_match('/set_(.*)/',$action,$reg)) {
    $code=$reg[1];
    $value=(GETPOST($code) ? GETPOST($code) : 1);
    if (dolibarr_set_const($db, $code, $value, 'chaine', 0, '', $conf->entity) > 0)
    {
        header("Location: ".$_SERVER["PHP_SELF"]);
        exit;
    }
    else
    {
        $error++;
        $errors[] = $db->lasterror();
    }
} elseif (preg_match('/del_(.*)/',$action,$reg)) {
    $code=$reg[1];
    if (dolibarr_del_const($db, $code, $conf->entity) > 0)
    {
        header("Location: ".$_SERVER["PHP_SELF"]);
        exit;
    }
    else
    {
        $error++;
        $errors[] = $db->lasterror();
    }
}

if ($action != '') {
    if (!$error) {
        setEventMessage($langs->trans('SetupSaved'));
    } else {
        setEventMessages('', $errors, 'errors');
    }
}


/*
 *	View
 */

$form = new Form($db);
$formpdfdownloadnotifier = new FormPdfDownloadNotifier($db);

llxHeader();

$linkback = '<a href="' . DOL_URL_ROOT . '/admin/modules.php">' . $langs->trans("BackToModuleList") . '</a>';
print load_fiche_titre($langs->trans("PdfDownloadNotifierSetup"), $linkback, 'title_setup');
print "<br>\n";

$head = pdfdownloadnotifier_admin_prepare_head();

print dol_get_fiche_head($head, 'settings', $langs->trans("Module163050Name"), 0, 'opendsi@pdfdownloadnotifier');


/**
 * General settings.
 */

print '<div id="settings_options"></div>';
print load_fiche_titre($langs->trans("PdfDownloadNotifierSettingsOptions"), '', '');
print '<form method="post" action="' . $_SERVER["PHP_SELF"] . '#settings_options">';
print '<input type="hidden" name="token" value="' . $_SESSION['newtoken'] . '">';
print '<input type="hidden" name="action" value="set_settings_options">';

print '<table class="noborder centpercent">';
print "<tr class=\"liste_titre\">\n";
print '<td>' . $langs->trans("Parameters") . '</td>' . "\n";
print '<td>' . $langs->trans("Description") . '</td>' . "\n";
print '<td class="right">' . $langs->trans("Value") . '</td>' . "\n";
print "</tr>\n";

// PDFDOWNLOADNOTIFIER_EMAIL_MODEL_USED_TO_NOTIFY_BY_EMAIL
print '<tr class="oddeven">' . "\n";
print '<td>' . $langs->trans("PdfDownloadNotifierEmailModelNotifyByMailName") . '</td>' . "\n";
print '<td>' . $langs->trans("PdfDownloadNotifierEmailModelNotifyByMailDesc") . '</td>' . "\n";
print '<td class="nowrap right">' . "\n";
print $form->selectarray('PDFDOWNLOADNOTIFIER_EMAIL_MODEL_USED_TO_NOTIFY_BY_EMAIL', $email_template_list, getDolGlobalString('PDFDOWNLOADNOTIFIER_EMAIL_MODEL_USED_TO_NOTIFY_BY_EMAIL'), 1);
print '</td></tr>' . "\n";

// PDFDOWNLOADNOTIFIER_DEFAULT_SEND_TO
print '<tr class="oddeven">' . "\n";
print '<td>' . $langs->trans("PdfDownloadNotifierDefaultSendToName") . '</td>' . "\n";
print '<td>' . $langs->trans("PdfDownloadNotifierDefaultSendToDesc") . '</td>' . "\n";
print '<td class="nowrap right">' . "\n";
print '<input type="text" name="PDFDOWNLOADNOTIFIER_DEFAULT_SEND_TO" size="50" value="' . dol_escape_htmltag(empty($conf->global->PDFDOWNLOADNOTIFIER_DEFAULT_SEND_TO)?'':$conf->global->PDFDOWNLOADNOTIFIER_DEFAULT_SEND_TO) . '" />' . "\n";
print '</td></tr>' . "\n";

print '</table>';

print '<br>';
print '<div align="center">';
print '<input type="submit" class="button" value="' . $langs->trans("Save") . '">';
print '</div>';

print '</form>';

/**
 * Elements options.
 */
print '<div id="elements_options"></div>';
print load_fiche_titre($langs->trans("PdfDownloadNotifierElementOptions"), '', '');
print '<form method="post" action="' . $_SERVER["PHP_SELF"] . '#elements_options">';
print '<input type="hidden" name="token" value="' . $_SESSION['newtoken'] . '">';
print '<input type="hidden" name="action" value="set_elements_options">';

print '<table class="noborder centpercent">';
print "<tr class=\"liste_titre\">\n";
print '<td>' . $langs->trans("Element") . '</td>' . "\n";
print '<td>' . $form->textwithpicto($langs->trans("PdfDownloadNotifierContactTypeNotifyByMail"), $langs->trans("PdfDownloadNotifierContactTypeNotifyByMailHelp")) . '</td>' . "\n";
print '<td class="center">' . $form->textwithpicto($langs->trans("PdfDownloadNotifierNotifyByMail"), $langs->trans("PdfDownloadNotifierNotifyByMailHelp")) . '</td>' . "\n";
print '<td class="center">' . $form->textwithpicto($langs->trans("PdfDownloadNotifierByEvent"), $langs->trans("PdfDownloadNotifierByEventHelp")) . '</td>' . "\n";
print "</tr>\n";

foreach ($element_list as $element_type => $element_info) {
	$element_prop = getElementProperties($element_type);
	if (is_array($element_prop) && !empty($conf->{$element_prop['module']}->enabled) && $conf->{$element_prop['module']}->enabled) {
		if (!empty($element_info['langs'])) $langs->load($element_info['langs']);
		dol_include_once('/' . $element_prop['classpath'] . '/' . $element_prop['classfile'] . '.class.php');
		$objecttmp = new $element_prop['classname']($db);
		$key = strtoupper($element_type);

		print '<tr class="oddeven">';

		// Element name
		print '<td>' . $langs->trans($element_info['label']) . '</td>';

		// Contact type to notify by email
		$emailNotifyContactTypeConstName = 'PDFDOWNLOADNOTIFIER_NOTIFY_CONTACT_TYPE_BY_EMAIL_' . $key;
		print '<td>';
		print $formpdfdownloadnotifier->multiselectTypeContact($objecttmp, empty($conf->global->$emailNotifyContactTypeConstName)?'':$conf->global->$emailNotifyContactTypeConstName, $emailNotifyContactTypeConstName, 'internal', 'position', 'minwidth500');
		print "</td>\n";

		// Notify by email
		$emailNotifyConstName = 'PDFDOWNLOADNOTIFIER_NOTIFY_BY_EMAIL_' . $key;
		print '<td class="center">';
		if (!empty($conf->use_javascript_ajax)) {
			print ajax_constantonoff($emailNotifyConstName);
		} else {
			if (empty($conf->global->$emailNotifyConstName)) {
				print '<a href="' . $_SERVER['PHP_SELF'] . '?action=set_' . $emailNotifyConstName . '">' . img_picto($langs->trans("Disabled"), 'switch_off') . '</a>';
			} else {
				print '<a href="' . $_SERVER['PHP_SELF'] . '?action=del_' . $emailNotifyConstName . '">' . img_picto($langs->trans("Enabled"), 'switch_on') . '</a>';
			}
		}
		print "</td>\n";

		// Notify by event
		$eventNotifyConstName = 'PDFDOWNLOADNOTIFIER_NOTIFY_BY_EVENT_' . $key;
		print '<td class="center">';
		if (!empty($conf->use_javascript_ajax)) {
			print ajax_constantonoff($eventNotifyConstName);
		} else {
			if (empty($conf->global->$eventNotifyConstName)) {
				print '<a href="' . $_SERVER['PHP_SELF'] . '?action=set_' . $eventNotifyConstName . '">' . img_picto($langs->trans("Disabled"), 'switch_off') . '</a>';
			} else {
				print '<a href="' . $_SERVER['PHP_SELF'] . '?action=del_' . $eventNotifyConstName . '">' . img_picto($langs->trans("Enabled"), 'switch_on') . '</a>';
			}
		}
		print "</td>\n";

		print "</tr>\n";
	}
}

print '</table>';

print '<br>';
print '<div align="center">';
print '<input type="submit" class="button" value="' . $langs->trans("Save") . '">';
print '</div>';

print '</form>';

print dol_get_fiche_end();


llxFooter();

$db->close();
