<?php
/*  Copyright (C) 2020      Open-DSI             <support@open-dsi.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 *	\file       pdfdownloadnotifier/class/html.formpdfdownloadnotifier.class.php
 *  \ingroup    pdfdownloadnotifier
 *	\brief      File of class with all html predefined components for PdfDownloadNotifier
 */

/**
 *	Class to manage generation of HTML components
 *	Only common components for PdfDownloadNotifier must be here.
 *
 */
class FormPdfDownloadNotifier
{
    public $db;
    public $error;
    public $num;

	/**
	 * @var Form  Instance of the form
	 */
	public $form;

    /**
     * Constructor
     *
     * @param   DoliDB $db Database handler
     */
    public function __construct($db)
    {
    	global $form;

		$this->db = $db;
		$this->form = $form;
    	if (!is_object($this->form)) {
			require_once DOL_DOCUMENT_ROOT . '/core/class/html.form.class.php';
			$this->form = new Form($this->db);
		}
    }

	/**
	 *  Return a multi select list with types of contacts
	 *
	 *  @param	CommonObject	$object         Object to use to find type of contact
	 *  @param  string|array	$selected       Default selected values
	 *  @param  string			$htmlname		HTML select name
	 *  @param  string			$source			Source ('internal' or 'external')
	 *  @param  string			$sortorder		Sort criteria ('position', 'code', ...)
	 *	@param  string			$morecss        Add more css style
	 *	@param  int				$translate		Translate and encode value
	 *  @param	int				$width			Force width of select box. May be used only when using jquery couch. Example: 250, 95%
	 *  @param	string			$moreattrib		Add more options on select component. Example: 'disabled'
	 *  @param	string			$elemtype		Type of element we show ('category', ...)
	 *  @param	string			$placeholder	String to use as placeholder
	 *  @param	int				$addjscombo		Add js combo
	 *  @return	string							Html text of the multi select list with types of contacts
	 */
	public function multiselectTypeContact($object, $selected, $htmlname = 'type', $source = 'internal', $sortorder = 'position', $morecss = '', $translate = 0, $width = 0, $moreattrib = '', $elemtype = '', $placeholder = '', $addjscombo = -1)
	{
		global $user, $langs;

		$out = '';

		if (is_object($object) && method_exists($object, 'liste_type_contact')) {
			$lesTypes = $object->liste_type_contact($source, $sortorder, 0, 1);
			if (is_array($lesTypes)) {
				$selected = is_array($selected) ? $selected : (is_string($selected) ? explode(',', $selected) : array());
				$out = $this->form->multiselectarray($htmlname, $lesTypes, $selected, 0, 0, $morecss, $translate, $width, $moreattrib, $elemtype, $placeholder, $addjscombo);
				if ($user->admin) $out .= ' ' . info_admin($langs->trans("YouCanChangeValuesForThisListFromDictionarySetup"), 1);
			} else {
				setEventMessages($object->error, $object->errors, 'errors');
			}
		}

		return $out;
	}
}

